@@ -15,12 +15,10 @@ import hashlib
 import logging
 import sys
 
-from oslo_utils import encodeutils
 from oslo_utils import timeutils
 # NOTE(stevemar): do not remove positional. We need this to stay for a while
 # since versions of auth_token require it here.
 from positional import positional  # noqa
-import prettytable
 import six
 
 from keystoneclient import exceptions
@@ -29,73 +27,6 @@ from keystoneclient import exceptions
 logger = logging.getLogger(__name__)
 
 
-# Decorator for cli-args
-def arg(*args, **kwargs):
-    def _decorator(func):
-        # Because of the semantics of decorator composition if we just append
-        # to the options list positional options will appear to be backwards.
-        func.__dict__.setdefault('arguments', []).insert(0, (args, kwargs))
-        return func
-    return _decorator
-
-
-def pretty_choice_list(l):
-    return ', '.join("'%s'" % i for i in l)
-
-
-def print_list(objs, fields, formatters={}, order_by=None):
-    pt = prettytable.PrettyTable([f for f in fields],
-                                 caching=False, print_empty=False)
-    pt.aligns = ['l' for f in fields]
-
-    for o in objs:
-        row = []
-        for field in fields:
-            if field in formatters:
-                row.append(formatters[field](o))
-            else:
-                field_name = field.lower().replace(' ', '_')
-                data = getattr(o, field_name, '')
-                if data is None:
-                    data = ''
-                row.append(data)
-        pt.add_row(row)
-
-    if order_by is None:
-        order_by = fields[0]
-    encoded = encodeutils.safe_encode(pt.get_string(sortby=order_by))
-    if six.PY3:
-        encoded = encoded.decode()
-    print(encoded)
-
-
-def _word_wrap(string, max_length=0):
-    """wrap long strings to be no longer than max_length."""
-    if max_length <= 0:
-        return string
-    return '\n'.join([string[i:i + max_length] for i in
-                     range(0, len(string), max_length)])
-
-
-def print_dict(d, wrap=0):
-    """pretty table prints dictionaries.
-
-    Wrap values to max_length wrap if wrap>0
-    """
-    pt = prettytable.PrettyTable(['Property', 'Value'],
-                                 caching=False, print_empty=False)
-    pt.aligns = ['l', 'l']
-    for (prop, value) in six.iteritems(d):
-        if value is None:
-            value = ''
-        value = _word_wrap(value, max_length=wrap)
-        pt.add_row([prop, value])
-    encoded = encodeutils.safe_encode(pt.get_string(sortby='Property'))
-    if six.PY3:
-        encoded = encoded.decode()
-    print(encoded)
-
-
 def find_resource(manager, name_or_id):
     """Helper for the _find_* methods."""
 
